@@ -16,12 +16,14 @@ import dash_core_components as dcc
 import webviz_core_components as wcc
 from dash.dependencies import Input, Output, State, ALL
 from dash.exceptions import PreventUpdate
+from webviz_config.webviz_assets import WEBVIZ_ASSETS
 from webviz_config.common_cache import CACHE
 from webviz_config.webviz_store import webvizstore
 from webviz_config import WebvizPluginABC
 from webviz_config import WebvizConfigTheme
 from webviz_config import WebvizSettings
 
+import webviz_subsurface
 from webviz_subsurface._models import EnsembleSetModel
 from webviz_subsurface._models import caching_ensemble_set_model_factory
 from .._abbreviations.reservoir_simulation import (
@@ -130,6 +132,14 @@ folder, to avoid risk of not extracting the right data.
     ):
 
         super().__init__()
+
+        WEBVIZ_ASSETS.add(
+            Path(webviz_subsurface.__file__).parent
+            / "_assets"
+            / "css"
+            / "block_options.css"
+        )
+
         self.column_keys = column_keys
         self.time_index = sampling
         if self.time_index not in ("daily", "monthly", "yearly"):
@@ -450,6 +460,7 @@ folder, to avoid risk of not extracting the right data.
                                 ),
                                 dcc.RadioItems(
                                     id=self.selectors_id("timeseries_visualization"),
+                                    className="block-options",
                                     options=[
                                         {
                                             "label": "Individual realizations",
@@ -949,7 +960,11 @@ def render_single_date_graph(
                     "Not unique data for column, date and ensemble combination."
                 )
             trace = _make_trace(
-                date_viz, df, col, col.split("_")[-1], colors[col.split("_")[-1]]
+                date_viz,
+                df,
+                col,
+                col.split("_filtered_on_")[-1],
+                colors[col.split("_filtered_on_")[-1]],
             )
             if trace is not None:
                 traces.append(trace)
@@ -1049,7 +1064,7 @@ def render_table(
                 raise ValueError("Not unique data for column and date combination.")
             table.append(
                 {
-                    "Group": col.split("_")[-1],
+                    "Group": col.split("_filtered_on_")[-1],
                     "Minimum": df["nanmin"].iat[0],
                     "Maximum": df["nanmax"].iat[0],
                     "Mean": df["nanmean"].iat[0],
@@ -1322,8 +1337,8 @@ def add_statistic_traces(
                 add_fanchart_traces(
                     stat_df=stat_df,
                     col=col,
-                    legend_group=col.split("_")[-1],
-                    color=groupby_color[groupby][col.split("_")[-1]],
+                    legend_group=col.split("_filtered_on_")[-1],
+                    color=groupby_color[groupby][col.split("_filtered_on_")[-1]],
                     line_shape=line_shape,
                 )
             )
